abacusai.eda_forecasting_analysis — AbacusAI documentation

# abacusai.eda_forecasting_analysis

## Classes

`ForecastingAnalysisGraphData` | Forecasting Analysis Graph Data representation.
`AbstractApiClass` |
`EdaForecastingAnalysis` | Eda Forecasting Analysis of the latest version of the data.

## Module Contents

class abacusai.eda_forecasting_analysis.ForecastingAnalysisGraphData(client, data=None, xAxis=None, yAxis=None, dataColumns=None, chartName=None, chartTypes=None, itemStatistics={}, chartDescriptions={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Forecasting Analysis Graph Data representation.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - data (list) – List of graph data

    - xAxis (str) – Feature that represents the x axis

    - yAxis (str) – Feature that represents the y axis

    - dataColumns (list) – Ordered name of the column for each rowwise data

    - chartName (str) – Name of the chart represented by the data

    - chartTypes (list) – Type of charts in that can exist in the current data.

    - itemStatistics (ItemStatistics) – In item wise charts, gives the mean, median, count, missing_percent, p10, p90, standard_deviation, min, max

    - chartDescriptions (EdaChartDescription) – List of descriptions of what the chart contains

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

class abacusai.eda_forecasting_analysis.AbstractApiClass(client, id)
  __eq__(other)

    Return self==value.

  _get_attribute_as_dict(attribute)

class abacusai.eda_forecasting_analysis.EdaForecastingAnalysis(client, primaryKeys=None, forecastingTargetFeature=None, timestampFeature=None, forecastFrequency=None, salesAcrossTime={}, cummulativeContribution={}, missingValueDistribution={}, historyLength={}, numRowsHistogram={}, productMaturity={}, seasonalityYear={}, seasonalityMonth={}, seasonalityWeekOfYear={}, seasonalityDayOfYear={}, seasonalityDayOfMonth={}, seasonalityDayOfWeek={}, seasonalityQuarter={}, seasonalityHour={}, seasonalityMinute={}, seasonalitySecond={}, autocorrelation={}, partialAutocorrelation={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Eda Forecasting Analysis of the latest version of the data.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - primaryKeys (list) – Name of the primary keys in the data

    - forecastingTargetFeature (str) – Feature in the data that represents the target.

    - timestampFeature (str) – Feature in the data that represents the timestamp column.

    - forecastFrequency (str) – Frequency of data, could be hourly, daily, weekly, monthly, quarterly or yearly.

    - salesAcrossTime (ForecastingAnalysisGraphData) – Data showing average, p10, p90, median sales across time

    - cummulativeContribution (ForecastingAnalysisGraphData) – Data showing what percent of items contribute to what amount of sales.

    - missingValueDistribution (ForecastingAnalysisGraphData) – Data showing missing or null value distribution

    - historyLength (ForecastingAnalysisGraphData) – Data showing length of history distribution

    - numRowsHistogram (ForecastingAnalysisGraphData) – Data showing number of rows for an item distribution

    - productMaturity (ForecastingAnalysisGraphData) – Data showing length of how long a product has been alive with average, p10, p90 and median

    - seasonalityYear (ForecastingAnalysisGraphData) – Data showing average, p10, p90, median sales across grouped years

    - seasonalityMonth (ForecastingAnalysisGraphData) – Data showing average, p10, p90, median sales across grouped months

    - seasonalityWeekOfYear (ForecastingAnalysisGraphData) – Data showing average, p10, p90, median sales across week of year seasonality

    - seasonalityDayOfYear (ForecastingAnalysisGraphData) – Data showing average, p10, p90, median sales across day of year seasonality

    - seasonalityDayOfMonth (ForecastingAnalysisGraphData) – Data showing average, p10, p90, median sales across day of month seasonality

    - seasonalityDayOfWeek (ForecastingAnalysisGraphData) – Data showing average, p10, p90, median sales across day of week seasonality

    - seasonalityQuarter (ForecastingAnalysisGraphData) – Data showing average, p10, p90, median sales across grouped quarters

    - seasonalityHour (ForecastingAnalysisGraphData) – Data showing average, p10, p90, median sales across grouped hours

    - seasonalityMinute (ForecastingAnalysisGraphData) – Data showing average, p10, p90, median sales across grouped minutes

    - seasonalitySecond (ForecastingAnalysisGraphData) – Data showing average, p10, p90, median sales across grouped seconds

    - autocorrelation (ForecastingAnalysisGraphData) – Data showing the correlation of the forecasting target and its lagged values at different time lags.

    - partialAutocorrelation (ForecastingAnalysisGraphData) – Data showing the correlation of the forecasting target and its lagged values, controlling for the effects of intervening lags.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict